#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-th
version:              0.1.7
visibility:           public
id:                   tasty-th-0.1.7-H2F2EOybSCcCHutQlYaVza
key:                  tasty-th-0.1.7-H2F2EOybSCcCHutQlYaVza
license:              BSD-3-Clause
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage:             http://github.com/bennofs/tasty-th
synopsis:             Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.

category:             Testing
abi:                  ab6cf6d57e491e09b8336cd93c38aadc
exposed:              True
exposed-modules:      Test.Tasty.TH
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-th-0.1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-th-0.1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-th
hs-libraries:         HStasty-th-0.1.7-H2F2EOybSCcCHutQlYaVza
depends:
    base-4.18.2.1 haskell-src-exts-1.23.1-AH4Ip6Ctvxv6HZmnCjNeVF
    tasty-1.5.2-9pLRGFImzQmLGzgIy8VqGZ template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html:         /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

